@@ -7,49 +7,33 @@ This includes two decorators, one for the handler function, and one to apply to
 functions.
 """
 
-# Exceptions
-from accustom.Exceptions import FailedToSendResponseException
-from accustom.Exceptions import DataIsNotDictException
-from accustom.Exceptions import InvalidResponseStatusException
-from accustom.Exceptions import NotValidRequestObjectException
-from accustom.Exceptions import ResponseTooLongException
-from accustom.Exceptions import NoPhysicalResourceIdException
-
-# Constants
-from accustom.constants import RequestType
-from accustom.constants import Status
-
-# Response
-from accustom.response import is_valid_event
-
-# RedactionConfig
-from accustom.redaction import RedactionConfig
-from accustom.redaction import StandaloneRedactionConfig
-
-# Required Libraries
-import logging
 import json
+import logging
 from functools import wraps
+from typing import Any, Callable, TypeVar, Union
 from uuid import uuid4
-from accustom.response import ResponseObject
-import six
+
 from boto3 import client
-from botocore.client import Config
 from botocore import exceptions as boto_exceptions
-from typing import Callable, TypeVar, Any, Union
+from botocore.client import Config
 from typing_extensions import ParamSpec
 
+from accustom.constants import RequestType, Status
+from accustom.Exceptions import (
+    DataIsNotDictException,
+    FailedToSendResponseException,
+    InvalidResponseStatusException,
+    NoPhysicalResourceIdException,
+    NotValidRequestObjectException,
+    ResponseTooLongException,
+)
+from accustom.redaction import RedactionConfig, StandaloneRedactionConfig
+from accustom.response import ResponseObject, is_valid_event
+
 logger = logging.getLogger(__name__)
 
-# Import Requests
-try:
-    import requests
-except ImportError:
-    from botocore.vendored import requests
-    logger.warning("botocore.vendored version of requests is deprecated. Please include requests in your code bundle.")
-
-_T = TypeVar('_T')
-_P = ParamSpec('_P')
+_T = TypeVar("_T")
+_P = ParamSpec("_P")
 
 # Time in milliseconds to set the alarm for (in milliseconds)
 # Should be set to twice the worst case response time to send to S3
@@ -57,8 +41,13 @@ _P = ParamSpec('_P')
 TIMEOUT_THRESHOLD = 2000
 
 
-def decorator(enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool = False,
-              redactConfig: RedactionConfig = None, timeoutFunction: bool = False) -> Callable[_P, _T]:
+# noinspection PyPep8Naming
+def decorator(
+    enforceUseOfClass: bool = False,
+    hideResourceDeleteFailure: bool = False,
+    redactConfig: RedactionConfig = None,
+    timeoutFunction: bool = False,
+) -> Callable[_P, _T]:
     """Decorate a function to add exception handling and emit CloudFormation responses.
 
     Usage with Lambda:
@@ -100,106 +89,109 @@ def decorator(enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool =
 
     """
 
+    # noinspection PyMissingOrEmptyDocstring
     def inner_decorator(func: Callable[_P, _T]) -> Callable[_P, _T]:
+        # noinspection PyMissingOrEmptyDocstring
         @wraps(func)
         def handler_wrapper(event: dict, context: Any, *args, **kwargs) -> Union[dict, str]:
             nonlocal redactConfig
             nonlocal timeoutFunction
-            logger.info('Request received, processing...')
+            logger.info("Request received, processing...")
             if not is_valid_event(event):
                 # If it is not a valid event we need to raise an exception
-                message = 'The event object passed is not a valid Request Object as per ' + \
-                          'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requests.html'
+                message = (
+                    "The event object passed is not a valid Request Object as per "
+                    + "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requests.html"
+                )
                 logger.error(message)
                 raise NotValidRequestObjectException(message)
 
             # Timeout Function Handler
-            if 'LambdaParentRequestId' in event:
+            if "LambdaParentRequestId" in event:
                 logger.info(
-                    f'This request has been invoked as a child, for parent logs please see request ID: '
+                    f"This request has been invoked as a child, for parent logs please see request ID: "
                     f'{event["LambdaParentRequestId"]}'
-                    )
+                )
             elif context is None and timeoutFunction:
                 logger.warning(
-                    'You cannot use the timeoutFunction option outside of Lambda. To suppress this warning' +
-                    ', set timeoutFunction to False'
-                    )
+                    "You cannot use the timeoutFunction option outside of Lambda. To suppress this warning, "
+                    "set timeoutFunction to False"
+                )
             elif timeoutFunction:
                 # Attempt to invoke the function. Depending on the error we get may continue execution or return
-                logger.info('Request has been invoked in Lambda with timeoutFunction set, attempting to invoke self')
+                logger.info("Request has been invoked in Lambda with timeoutFunction set, attempting to invoke self")
                 p_event = event.copy()
-                p_event['LambdaParentRequestId'] = context.aws_request_id
-                payload = json.dumps(p_event).encode('UTF-8')
+                p_event["LambdaParentRequestId"] = context.aws_request_id
+                payload = json.dumps(p_event).encode("UTF-8")
                 timeout = (context.get_remaining_time_in_millis() - TIMEOUT_THRESHOLD) / 1000
                 # Edge case where time is set to very low timeout, use half the timeout threshold as the timeout for
                 # the Lambda Function
-                if timeout <= 0: timeout = TIMEOUT_THRESHOLD / 2000
-                config = Config(connect_timeout=2, read_timeout=timeout, retries={'max_attempts': 0})
-                b_lambda = client('lambda', config=config)
+                if timeout <= 0:
+                    timeout = TIMEOUT_THRESHOLD / 2000
+                config = Config(connect_timeout=2, read_timeout=timeout, retries={"max_attempts": 0})
+                b_lambda = client("lambda", config=config)
 
                 # Normally we would just do a catch-all error handler but in this case we want to be paranoid
                 try:
                     response = b_lambda.invoke(
-                        FunctionName=context.invoked_function_arn,
-                        InvocationType='RequestResponse', Payload=payload
-                        )
+                        FunctionName=context.invoked_function_arn, InvocationType="RequestResponse", Payload=payload
+                    )
                     # Further checks
-                    if 'FunctionError' in response:
-                        response.get('Payload', ''.encode('UTF-8'))
-                        message = f'Invocation got an error: {payload.decode()}'
+                    if "FunctionError" in response:
+                        response.get("Payload", "".encode("UTF-8"))
+                        message = f"Invocation got an error: {payload.decode()}"
                         logger.error(message)
                         return ResponseObject(reason=message, responseStatus=Status.FAILED).send(event, context)
                     else:
                         # In this case the function returned without error which means we can assume the chained
                         # invocation sent a response, so we do not have too.
-                        logger.info('Completed execution of chained invocation, returning payload')
-                        response.get('Payload', ''.encode('UTF-8'))
+                        logger.info("Completed execution of chained invocation, returning payload")
+                        response.get("Payload", "".encode("UTF-8"))
                         return payload.decode()
 
                 except boto_exceptions.ClientError as e:
                     logger.warning(
-                        f'Caught exception {str(e)} while trying to invoke function. Running handler locally.'
-                        )
+                        f"Caught exception {str(e)} while trying to invoke function. Running handler locally."
+                    )
                     logger.warning(
-                        'You cannot use the timeoutFunction option without the ability for the function to' +
-                        ' invoke itself. To suppress this warning, set timeoutFunction to False'
-                        )
+                        "You cannot use the timeoutFunction option without the ability for the function to invoke "
+                        "itself. To suppress this warning, set timeoutFunction to False"
+                    )
                 except boto_exceptions.ConnectionError as e:
-                    logger.error(f'Got error {str(e)} while trying to invoke function. Running handler locally')
+                    logger.error(f"Got error {str(e)} while trying to invoke function. Running handler locally")
                     logger.error(
-                        'You cannot use the timeoutFunction option without the ability to connect to the ' +
-                        'Lambda API from within the function. As we may not have time to execute the ' +
-                        'function, returning failure.'
-                        )
+                        "You cannot use the timeoutFunction option without the ability to connect to the Lambda API "
+                        "from within the function. As we may not have time to execute the function, returning failure."
+                    )
                     return ResponseObject(
-                        reason='Unable to call Lambda to do chained invoke, returning failure.',
-                        responseStatus=Status.FAILED
-                        ).send(event, context)
+                        reason="Unable to call Lambda to do chained invoke, returning failure.",
+                        responseStatus=Status.FAILED,
+                    ).send(event, context)
                 except boto_exceptions.ReadTimeoutError:
                     # This should be a critical failure
-                    logger.error('Waited the read timeout and function did not return, returning an error')
+                    logger.error("Waited the read timeout and function did not return, returning an error")
                     return ResponseObject(
-                        reason='Lambda function timed out, returning failure.',
-                        responseStatus=Status.FAILED
-                        ).send(event, context)
+                        reason="Lambda function timed out, returning failure.", responseStatus=Status.FAILED
+                    ).send(event, context)
                 except Exception as e:
-                    message = f'Got an {e.__class__} I did not understand while trying to invoke child function: ' \
-                              f'{str(e)}'
+                    message = (
+                        f"Got an {e.__class__} I did not understand while trying to invoke child function: " f"{str(e)}"
+                    )
                     logger.error(message)
                     return ResponseObject(reason=message, responseStatus=Status.FAILED).send(event, context)
 
             # Debug Logging Handler
             if logger.getEffectiveLevel() <= logging.DEBUG:
                 if context is not None:
-                    logger.debug(f'Running request with Lambda RequestId: {context.aws_request_id}')
+                    logger.debug(f"Running request with Lambda RequestId: {context.aws_request_id}")
                 if redactConfig is not None and isinstance(redactConfig, (StandaloneRedactionConfig, RedactionConfig)):
                     # noinspection PyProtectedMember
-                    logger.debug('Request Body:\n' + json.dumps(redactConfig._redact(event)))
+                    logger.debug("Request Body: " + json.dumps(redactConfig._redact(event)))
                 elif redactConfig is not None:
-                    logger.warning('A non valid RedactionConfig was provided, and ignored')
-                    logger.debug('Request Body:\n' + json.dumps(event))
+                    logger.warning("A non valid RedactionConfig was provided, and ignored")
+                    logger.debug("Request Body: " + json.dumps(event))
                 else:
-                    logger.debug('Request Body:\n' + json.dumps(event))
+                    logger.debug("Request Body: " + json.dumps(event))
 
             try:
                 logger.info(f'Running CloudFormation request {event["RequestId"]} for stack: {event["StackId"]}')
@@ -211,8 +203,8 @@ def decorator(enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool =
                 result = ResponseObject(
                     physicalResourceId=str(uuid4()) if context is None else None,
                     reason=f'Function {func.__name__} failed due to exception "{str(e)}"',
-                    responseStatus=Status.FAILED
-                    )
+                    responseStatus=Status.FAILED,
+                )
                 logger.error(result.reason)
 
             if not isinstance(result, ResponseObject):
@@ -220,56 +212,57 @@ def decorator(enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool =
                 # failure if it is an invalid response type, or if the enforceUseOfClass is explicitly or implicitly set
                 if context is None:
                     result = ResponseObject(
-                        reason=f'Response Object of type {result.__class__} was not a ResponseObject and there is no '
-                               f'Lambda Context',
-                        responseStatus=Status.FAILED
-                        )
+                        reason=f"Response Object of type {result.__class__} was not a ResponseObject and there is no "
+                        f"Lambda Context",
+                        responseStatus=Status.FAILED,
+                    )
                     logger.error(result.reason)
                 elif enforceUseOfClass:
                     result = ResponseObject(
-                        reason=f'Response Object of type {result.__class__} was not a ResponseObject instance and '
-                               f'enforceUseOfClass set to true',
-                        responseStatus=Status.FAILED
-                        )
+                        reason=f"Response Object of type {result.__class__} was not a ResponseObject instance and "
+                        f"enforceUseOfClass set to true",
+                        responseStatus=Status.FAILED,
+                    )
                     logger.error(result.reason)
                 elif result is False:
                     result = ResponseObject(
-                        reason=f'Function {func.__name__} returned False.',
-                        responseStatus=Status.FAILED
-                        )
+                        reason=f"Function {func.__name__} returned False.", responseStatus=Status.FAILED
+                    )
                     logger.debug(result.reason)
                 elif isinstance(result, dict):
                     result = ResponseObject(data=result)
-                elif isinstance(result, six.string_types):
-                    result = ResponseObject(data={'Return': result})
+                elif isinstance(result, str):
+                    result = ResponseObject(data={"Return": result})
                 elif result is None or result is True:
                     result = ResponseObject()
                 else:
                     result = ResponseObject(
-                        reason=f'Return value from Function {func.__name__} is of unsupported type {result.__class__}',
-                        responseStatus=Status.FAILED
-                        )
+                        reason=f"Return value from Function {func.__name__} is of unsupported type {result.__class__}",
+                        responseStatus=Status.FAILED,
+                    )
                     logger.error(result.reason)
 
             # This block will hide resources on delete failure if the flag is set to true
-            if event['RequestType'] == RequestType.DELETE and result.responseStatus == Status.FAILED \
-                    and hideResourceDeleteFailure:
-                logger.warning('Hiding Resource DELETE request failure')
+            if (
+                event["RequestType"] == RequestType.DELETE
+                and result.responseStatus == Status.FAILED
+                and hideResourceDeleteFailure
+            ):
+                logger.warning("Hiding Resource DELETE request failure")
                 if result.data is not None:
                     if not result.squashPrintResponse:
-                        logger.debug('Data:\n' + json.dumps(result.data))
+                        logger.debug("Data:\n" + json.dumps(result.data))
                     else:
-                        logger.debug('Data: [REDACTED]')
-                if result.reason is not None: logger.debug(f'Reason: {result.reason}')
-                if result.physicalResourceId is not None: logger.debug(
-                    f'PhysicalResourceId: {result.physicalResourceId}'
-                    )
+                        logger.debug("Data: [REDACTED]")
+                if result.reason is not None:
+                    logger.debug(f"Reason: {result.reason}")
+                if result.physicalResourceId is not None:
+                    logger.debug(f"PhysicalResourceId: {result.physicalResourceId}")
                 result = ResponseObject(
-                    reason='There may be resources created by this Custom Resource that have not been cleaned' +
-                           'up despite the fact this resource is in DELETE_COMPLETE',
+                    reason="There may be resources created by this Custom Resource that have not been cleaned up "
+                    "despite the fact this resource is in DELETE_COMPLETE",
                     physicalResourceId=result.physicalResourceId,
-                    responseStatus=Status.SUCCESS
-                    )
+                )
 
             try:
                 return_value = result.send(event, context)
@@ -277,50 +270,40 @@ def decorator(enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool =
                 message = "An unexpected error has occurred, No Physical Resource ID provided in response."
                 logger.error(message)
                 result = ResponseObject(
-                    reason=message,
-                    physicalResourceId=result.physicalResourceId,
-                    responseStatus=Status.FAILED
-                    )
+                    reason=message, physicalResourceId=result.physicalResourceId, responseStatus=Status.FAILED
+                )
                 return_value = result.send(event, context)
             except InvalidResponseStatusException:
                 message = f'Status provided "{result.responseStatus}" is not a valid status.'
                 logger.error(message)
                 result = ResponseObject(
-                    reason=message,
-                    physicalResourceId=result.physicalResourceId,
-                    responseStatus=Status.FAILED
-                    )
+                    reason=message, physicalResourceId=result.physicalResourceId, responseStatus=Status.FAILED
+                )
                 return_value = result.send(event, context)
             except DataIsNotDictException as e:
-                message = f'Malformed Data Block in Response, Exception; {str(e)}'
+                message = f"Malformed Data Block in Response, Exception; {str(e)}"
                 logger.error(message)
                 result = ResponseObject(
-                    reason=message,
-                    physicalResourceId=result.physicalResourceId,
-                    responseStatus=Status.FAILED
-                    )
+                    reason=message, physicalResourceId=result.physicalResourceId, responseStatus=Status.FAILED
+                )
                 return_value = result.send(event, context)
             except ResponseTooLongException as e:
                 message = str(e)
                 logger.error(message)
                 result = ResponseObject(
-                    reason=message,
-                    physicalResourceId=result.physicalResourceId,
-                    responseStatus=Status.FAILED
-                    )
+                    reason=message, physicalResourceId=result.physicalResourceId, responseStatus=Status.FAILED
+                )
                 return_value = result.send(event, context)
             except FailedToSendResponseException as e:
                 # Capturing and re-raising exception to prevent generic exception handler from kicking in
                 raise e
             except Exception as e:
                 # Generic error capture
-                message = f'Malformed request, Exception: {str(e)}'
+                message = f"Malformed request, Exception: {str(e)}"
                 logger.error(message)
                 result = ResponseObject(
-                    reason=message,
-                    physicalResourceId=result.physicalResourceId,
-                    responseStatus=Status.FAILED
-                    )
+                    reason=message, physicalResourceId=result.physicalResourceId, responseStatus=Status.FAILED
+                )
                 return_value = result.send(event, context)
             return return_value
 
@@ -329,89 +312,93 @@ def decorator(enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool =
     return inner_decorator
 
 
-def rdecorator(decoratorHandleDelete: bool = False,
-               expectedProperties: list = None,
-               genUUID: bool = True) -> Callable[_P, _T]:
+# noinspection PyPep8Naming
+def rdecorator(
+    decoratorHandleDelete: bool = False, expectedProperties: list = None, genUUID: bool = True
+) -> Callable[_P, _T]:
     """Decorate a function to add input validation for resource handler functions.
 
-        Usage with Lambda:
-            import accustom
-            @accustom.rdecorator(expectedProperties=['key1','key2'],genUUID=False)
-            def resource_function(event, context):
-                sum = (float(event['ResourceProperties']['key1']) +
-                       float(event['ResourceProperties']['key2']))
-                return { 'sum' : sum }
-            @accustom.decorator()
-            def function_handler(event, context)
-                return resource_function(event,context)
+    Usage with Lambda:
+        import accustom
+        @accustom.rdecorator(expectedProperties=['key1','key2'],genUUID=False)
+        def resource_function(event, context):
+            sum = (float(event['ResourceProperties']['key1']) +
+                   float(event['ResourceProperties']['key2']))
+            return { 'sum' : sum }
+        @accustom.decorator()
+        def function_handler(event, context)
+            return resource_function(event,context)
 
-        Usage outside Lambda:
-            import accustom
-            @accustom.rdecorator(expectedProperties=['key1','key2'])
-            def resource_function(event, context=None)
-                sum = (float(event['ResourceProperties']['key1']) +
-                       float(event['ResourceProperties']['key2']))
-                r = accustom.ResponseObject(data={'sum':sum},physicalResourceId=event['PhysicalResourceId'])
-                return r
-            @accustom.decorator()
-            def function_handler(event)
-                return resource_function(event)
+    Usage outside Lambda:
+        import accustom
+        @accustom.rdecorator(expectedProperties=['key1','key2'])
+        def resource_function(event, context=None)
+            sum = (float(event['ResourceProperties']['key1']) +
+                   float(event['ResourceProperties']['key2']))
+            r = accustom.ResponseObject(data={'sum':sum},physicalResourceId=event['PhysicalResourceId'])
+            return r
+        @accustom.decorator()
+        def function_handler(event)
+            return resource_function(event)
 
-        Args:
-            decoratorHandleDelete (boolean): When set to true, if a delete request is made in event the decorator will
-                return a ResponseObject with a with SUCCESS without actually executing the decorated function
-            genUUID (boolean): When set to true, if the PhysicalResourceId in the event is not set, automatically
-                generate a UUID4 and put it in the PhysicalResourceId field.
-            expectedProperties (list of expected properties): Pass in a list or tuple of properties that you want to
-                check for before running the decorated function.
+    Args:
+        decoratorHandleDelete (boolean): When set to true, if a delete request is made in event the decorator will
+            return a ResponseObject with a with SUCCESS without actually executing the decorated function
+        genUUID (boolean): When set to true, if the PhysicalResourceId in the event is not set, automatically
+            generate a UUID4 and put it in the PhysicalResourceId field.
+        expectedProperties (list of expected properties): Pass in a list or tuple of properties that you want to
+            check for before running the decorated function.
 
-        Returns:
-            The result of the decorated function, or a ResponseObject with SUCCESS depending on the event and flags.
+    Returns:
+        The result of the decorated function, or a ResponseObject with SUCCESS depending on the event and flags.
 
-        Raises:
-            NotValidRequestObjectException
-            Any exception raised by the decorated function.
+    Raises:
+        NotValidRequestObjectException
+        Any exception raised by the decorated function.
 
 
-        Decorated Function Arguments:
-            event (dict): The request object being processed (Required).
+    Decorated Function Arguments:
+        event (dict): The request object being processed (Required).
     """
 
+    # noinspection PyMissingOrEmptyDocstring
     def resource_decorator_inner(func: Callable[_P, _T]) -> Callable[_P, _T]:
+        # noinspection PyMissingOrEmptyDocstring
         @wraps(func)
         def resource_decorator_handler(event: dict, *args, **kwargs) -> Union[ResponseObject, dict, str]:
             if not is_valid_event(event):
                 # If it is not a valid event we need to raise an exception
-                message = 'The event object passed is not a valid Request Object as per ' + \
-                          'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requests.html'
+                message = (
+                    "The event object passed is not a valid Request Object as per "
+                    + "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requests.html"
+                )
                 logger.error(message)
                 raise NotValidRequestObjectException(message)
             logger.info(f'Supported resource {event["ResourceType"]}')
 
             # Set the Physical Resource ID to a randomly generated UUID if it is not present
-            if genUUID and 'PhysicalResourceId' not in event:
-                event['PhysicalResourceId'] = str(uuid4())
+            if genUUID and "PhysicalResourceId" not in event:
+                event["PhysicalResourceId"] = str(uuid4())
                 logger.info(f'Set PhysicalResourceId to {event["PhysicalResourceId"]}')
 
             # Handle Delete when decoratorHandleDelete is set to True
-            if decoratorHandleDelete and event['RequestType'] == RequestType.DELETE:
-                logger.info(f'Request type {RequestType.DELETE} detected, returning success without calling function')
-                return ResponseObject(physicalResourceId=event['PhysicalResourceId'])
+            if decoratorHandleDelete and event["RequestType"] == RequestType.DELETE:
+                logger.info(f"Request type {RequestType.DELETE} detected, returning success without calling function")
+                return ResponseObject(physicalResourceId=event["PhysicalResourceId"])
 
             # Validate important properties exist
             if expectedProperties is not None and isinstance(expectedProperties, (list, tuple)):
                 for index, item in enumerate(expectedProperties):
-                    if item not in event['ResourceProperties']:
-                        err_msg = f'Property {item} missing, sending failure signal'
+                    if item not in event["ResourceProperties"]:
+                        err_msg = f"Property {item} missing, sending failure signal"
                         logger.info(err_msg)
                         return ResponseObject(
-                            reason=err_msg, responseStatus=Status.FAILED,
-                            physicalResourceId=event['PhysicalResourceId']
-                            )
+                            reason=err_msg, responseStatus=Status.FAILED, physicalResourceId=event["PhysicalResourceId"]
+                        )
 
             # If a list or tuple was not provided then log a warning
             elif expectedProperties is not None:
-                logger.warning('expectedProperties passed to decorator is not a list, properties were not validated.')
+                logger.warning("expectedProperties passed to decorator is not a list, properties were not validated.")
 
             # Pre-validation complete, calling function
             return func(event, *args, **kwargs)
@@ -421,9 +408,16 @@ def rdecorator(decoratorHandleDelete: bool = False,
     return resource_decorator_inner
 
 
-def sdecorator(decoratorHandleDelete: bool = False, expectedProperties: list = None, genUUID: bool = True,
-               enforceUseOfClass: bool = False, hideResourceDeleteFailure: bool = False,
-               redactConfig: RedactionConfig = None, timeoutFunction: bool = True) -> Callable[_P, _T]:
+# noinspection PyPep8Naming
+def sdecorator(
+    decoratorHandleDelete: bool = False,
+    expectedProperties: list = None,
+    genUUID: bool = True,
+    enforceUseOfClass: bool = False,
+    hideResourceDeleteFailure: bool = False,
+    redactConfig: RedactionConfig = None,
+    timeoutFunction: bool = True,
+) -> Callable[_P, _T]:
     """Decorate a function to add input validation for resource handler functions, exception handling and send
     CloudFormation responses.
 
@@ -467,17 +461,24 @@ def sdecorator(decoratorHandleDelete: bool = False, expectedProperties: list = N
          FailedToSendResponseException
          NotValidRequestObjectException
     """
-    if redactConfig is not None and not isinstance(redactConfig, StandaloneRedactionConfig) and \
-            logger.getEffectiveLevel() <= logging.DEBUG:
-        logger.warning('A non valid StandaloneRedactionConfig was provided, and ignored')
+    if (
+        redactConfig is not None
+        and not isinstance(redactConfig, StandaloneRedactionConfig)
+        and logger.getEffectiveLevel() <= logging.DEBUG
+    ):
+        logger.warning("A non valid StandaloneRedactionConfig was provided, and ignored")
         redactConfig = None
 
+    # noinspection PyMissingOrEmptyDocstring
     def standalone_decorator_inner(func: Callable[_P, _T]) -> Callable[_P, _T]:
+        # noinspection PyMissingOrEmptyDocstring
         @wraps(func)
         @decorator(
-            enforceUseOfClass=enforceUseOfClass, hideResourceDeleteFailure=hideResourceDeleteFailure,
-            redactConfig=redactConfig, timeoutFunction=timeoutFunction
-            )
+            enforceUseOfClass=enforceUseOfClass,
+            hideResourceDeleteFailure=hideResourceDeleteFailure,
+            redactConfig=redactConfig,
+            timeoutFunction=timeoutFunction,
+        )
         @rdecorator(decoratorHandleDelete=decoratorHandleDelete, expectedProperties=expectedProperties, genUUID=genUUID)
         def standalone_decorator_handler(event: dict, context: Any, *args, **kwargs) -> Union[dict, str]:
             return func(event, context, *args, **kwargs)
